@@ -51,7 +51,7 @@ class LeadImageExtender(object):
         LeadimageImageField(IMAGE_FIELD_NAME,
           required = False,
           storage = AnnotationStorage(migrate=True),
-          languageIndependent = True,
+          languageIndependent = False,
           max_size = zconf.ATNewsItem.max_image_dimension,
           validators = (('isNonEmptyFile', V_REQUIRED),
                                ('checkNewsImageMaxSize', V_REQUIRED)),
